echologrus

package module
v0.0.0-...-e48b948 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 6, 2017 License: BSD-3-Clause Imports: 4 Imported by: 0

README

echo-logrus

Overview

Package echologrus provides a middleware for echo that logs request details via the logrus logging library.

License

3-clause BSD. A copy is included with the source.

Documentation

Overview

Package echologrus provides a middleware for echo that logs request details via the logrus logging library

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func New

func New() echo.MiddlewareFunc

New returns a new middleware handler with a default name and logger

func NewWithName

func NewWithName(name string) echo.MiddlewareFunc

NewWithName returns a new middleware handler with the specified name

func NewWithNameAndLogger

func NewWithNameAndLogger(name string, l *logrus.Logger) echo.MiddlewareFunc

NewWithNameAndLogger returns a new middleware handler with the specified name and logger

Types

This section is empty.

Jump to